@@ -17,7 +17,7 @@ Creating and registering a custom encoder is as easy as:
 ...     return dict(obj)
 >>>
 
-In this case, `MyClass` can be made JSON-serializable simply by calling
+In this case, ``MyClass`` can be made JSON-serializable simply by calling
 :class:`dict <python:dict>` on it. If your class requires more complicated logic
 to make it JSON-serializable, do that here.
 
@@ -38,7 +38,7 @@ Or to dump to a file:
 ...
 >>>
 
-`sdjson` also provides access to :func:`load <python:json.load>`,
+``sdjson`` also provides access to :func:`load <python:json.load>`,
 :func:`loads <python:json.loads>`, :class:`~python:json.JSONDecoder`,
 :class:`~python:json.JSONDecodeError`, and :class:`~python:json.JSONEncoder`
 from the :mod:`~python:json` module, allowing you to use ``sdjson`` as a drop-in replacement
@@ -64,10 +64,7 @@ different one it is not necessary to call this function: the
 the given class.
 
 
-
 TODO: This module does not currently support custom decoders, but might in the future.
-
-
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -111,7 +108,7 @@ __author__ = "Dominic Davis-Foster"
 __copyright__ = "2020 Dominic Davis-Foster"
 
 __license__ = "LGPLv3+"
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 __email__ = "dominic@davis-foster.co.uk"
 
 # stdlib
@@ -180,7 +177,7 @@ unregister_encoder = _Encoders.unregister
 def dump(obj, fp, **kwargs):
 	"""
 	Serialize custom Python classes to JSON.
-	Custom classes can be registered using the ``@dump.register(<type>)`` decorator.
+	Custom classes can be registered using the ``@encoders.register(<type>)`` decorator.
 	"""
 
 	iterable = dumps(obj, **kwargs)
@@ -198,7 +195,7 @@ def dumps(
 		):
 	"""
 	Serialize custom Python classes to JSON.
-	Custom classes can be registered using the ``@dump.register(<type>)`` decorator.
+	Custom classes can be registered using the ``@encoders.register(<type>)`` decorator.
 	"""
 	
 	if (
@@ -290,11 +287,11 @@ JSONDecodeError = json.JSONDecodeError
 
 # Custom encoder for sdjson
 class _CustomEncoder(JSONEncoder):
-	def default(self, o):
+	def default(self, obj):
 		for type_, handler in encoders.registry.items():
-			if isinstance(o, type_) and type_ is not object:
-				return handler(o)
-		return super().default(o)
+			if isinstance(obj, type_) and type_ is not object:
+				return handler(obj)
+		return super().default(obj)
 
 
 _default_encoder = _CustomEncoder(
